OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Kişiler",
    "Download" : "İndir",
    "Copy link" : "Bağlantıyı kopyala",
    "Click to copy the link to your clipboard" : "Bağlantıyı panoya almak için kopyala üzerine tıklayın",
    "Toggle sharing" : "Paylaşımı Değiştir",
    "Delete" : "Sil",
    "Rename" : "Yeniden Adlandır",
    "Share with users or groups" : "Kullanıcı ve gruplarla paylaş",
    "can edit" : "düzenleyebilir",
    "Close" : "Kapat",
    "Enabled" : "Etkin",
    "Disabled" : "Devre Dışı",
    "Copied!" : "Kopyalandı!",
    "Not supported!" : "Desteklenmiyor!",
    "Press ⌘-C to copy." : "Kopyalamak için ⌘-C tuşlarına basın.",
    "Press Ctrl-C to copy." : "Kopyalamak için Ctrl-C tuşlarına basın.",
    "Address book name" : "Adres defteri adı",
    "Only these special characters are allowed: -_.!?#|()" : "Yalnız şu özel karakterler kullanılabilir: -_.!?#|()",
    "Address book could not be created." : "Adres defteri oluşturulamadı.",
    "The selected image is too big (max 1MB)" : "Seçilmiş görsel çok büyük (en fazla 1MB)",
    "This card is corrupted and has been fixed. Please check the data and trigger a save to make the changes permanent." : "Bu kart bozulmuş ve onarılacak. Lütfen verileri denetleyin ve değişikliklerin geçerli olması için kaydedin.",
    "No contacts in here" : "Burada herhangi bir kişi yok",
    "Name" : "Ad",
    "Organization" : "Kurum",
    "Title" : "Başlık",
    "Add field …" : "Alan ekle…",
    "Save changes" : "Değişiklikleri kaydet",
    "Address book" : "Adres defteri",
    "Loading contacts …" : "Kişiler yükleniyor…",
    "Import into" : "Şunun içine aktar",
    "Importing..." : "İçe aktarılıyor...",
    "Select your addressbook" : "Adres defterinizi seçin",
    "Import is disabled because no writable address book had been found." : "Yazılabilecek bir adres defteri bulunamadığından içe aktarım devre dışı bırakıldı.",
    "No search result for {query}" : "{query} aramasından bir sonuç alınamadı",
    "All contacts" : "Tüm kişiler",
    "Post office box" : "Posta kutusu",
    "Postal code" : "Posta kodu",
    "City" : "İlçe",
    "State or province" : "Şehir",
    "Country" : "Ülke",
    "Address" : "Adres",
    "(new group)" : "(yeni grup)",
    "Last name" : "Soyad",
    "First name" : "Ad",
    "Additional names" : "Ek adlar",
    "Prefix" : "Ön ek",
    "Suffix" : "Son ek",
    "Importing into" : "Şunun içine aktarılıyor",
    "New contact" : "Yeni kişi",
    "Not grouped" : "Gruplanmamış",
    "Sort by" : "Sıralama",
    "There is no address book available to create a contact." : "Kişi kaydının eklenebileceği bir adres defteri yok.",
    "{addressbook} shared by {owner}" : "{owner} tarafından paylaşılmış {addressbook}",
    "Contact not found." : "Kişi bulunamadı.",
    "You don't have permission to write to this addressbook." : "Bu adres defterine yazma izniniz yok.",
    "Contact could not be created." : "Kişi oluşturulamadı.",
    "No contacts in file. Only vCard files are allowed." : "Dosyada herhangi bir kişi yok. Yalnız vCard dosyaları kullanılabilir.",
    "Only vCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Yalnız vCard sürüm 4.0 (RFC6350) ya da sürüm 3.0 (RFC2426) desteklenir.",
    "Contact could not be moved." : "Kişi taşınamadı.",
    "Contact could not be saved." : "Kişi kaydedilemedi.",
    "Waiting for the server to be ready…" : "Sunucunun hazır olması bekleniyor…",
    "Importing…" : "İçe aktarılıyor…",
    "Display name" : "Görüntülenecek ad",
    "Nickname" : "Kısaltma",
    "Detailed name" : "Ayrıntılı ad",
    "Notes" : "Notlar",
    "Website" : "Web sitesi",
    "Federated Cloud ID" : "Birleşmiş Bulut Kimliği",
    "Home" : "Ev",
    "Work" : "İş",
    "Other" : "Diğer",
    "Groups" : "Gruplar",
    "Birthday" : "Doğum günü",
    "Anniversary" : "Yıl dönümü",
    "Date of death" : "Ölüm tarihi",
    "Email" : "E-posta",
    "Instant messaging" : "Anlık iletişim",
    "Phone" : "Telefon",
    "Mobile" : "Cep telefonu",
    "Work mobile" : "İş cep telefonu",
    "Fax" : "Faks",
    "Fax home" : "Ev faksı",
    "Fax work" : "İş faksı",
    "Pager" : "Çağrı cihazı",
    "Voice" : "Ses",
    "Car" : "Araç telefonu",
    "Work pager" : "İş çağrı cihazı",
    "Social network" : "Sosyal ağ",
    "Relationship" : "İlişki",
    "Spouse" : "Eş",
    "Child" : "Çocuk",
    "Mother" : "Anne",
    "Father" : "Baba",
    "Parent" : "Ebeveyn",
    "Brother" : "Erkek Kardeş",
    "Sister" : "Kız Kardeş",
    "Relative" : "Akraba",
    "Friend" : "Arkadaş",
    "Colleague" : "Çalışma Arkadaşı",
    "Manager" : "Yönetici",
    "Assistant" : "Yardımcı",
    "Gender" : "Cinsiyet",
    "Female" : "Kadın",
    "Male" : "Erkek",
    "Details" : "Ayrıntılar",
    "Settings" : "Ayarlar"
},
"nplurals=2; plural=(n > 1);");
